function ifo = IFOModel_CE1(arm_len, Tsrm, sqzdB)
  % Modified GWINC model for cryogenic CE
  if nargin < 1 || isempty(arm_len)
    arm_len = 40e3;
  end
  if nargin < 2 || isempty(Tsrm)
    Tsrm = 800 / arm_len;  % gives 40% for 4km
  end
  if nargin < 3 || isempty(sqzdB)
    sqzdB = 15;  % gives 10dB measured at HF
  end
  if Tsrm > 1
    Tsrm = Tsrm / arm_len;  % set Tsrm based on length
  end

  % start with base model
  ifo = IFOModel;
  
  %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
  % Adjust IFO parameters
  
  % set length
  gE = interp1([4e3, 40e3], [-0.8, -0.15], arm_len);
  gI = interp1([4e3, 40e3], [-1.0, -0.15], arm_len);
  ifo.Infrastructure.Length = arm_len;
  ifo.Optics.Curvature.ITM = arm_len / (1 - gI);      % ROC of ITM
  ifo.Optics.Curvature.ETM = arm_len / (1 - gE);      % ROC of ETM
  
  % set laser power
  ifo.Laser.Power = 150;
  
  % add Newtonian Noise cancellation
  ifo.Seismic.Omicron = 10;
  
  % Optics
  ifo.Optics.SRM.Transmittance  = Tsrm;     % Transmittance of SRM  
  ifo.Optics.SRM.Tunephase = 0.0;           % SRM tuning
  ifo.Optics.Quadrature.dc = pi/2;          % demod/detection/homodyne phase
  
  % scale up suspension
  ifo.Suspension.Fiber.Radius = 150e-6;     %   and a bit thinner (was 200)
  ifo = scaleSusMass(ifo, 8);               % scale up mass by 4
  ifo = scaleSusLength(ifo, 2);             % scale length by 2
  
  % need penultimate stage thermal noise to be low
  ifo.Suspension.Stage(2).WireMaterial = 'Silica';
  
  % coatings... assume we make AlGaAs work
  %ifo = setCoatingAlGaAs(ifo);
  % not really AlGaAs... need thermo-optic optimized coatings for RT
  %ifo.Materials.Coating.Phihighn = 2e-5;               % guess
  %ifo.Materials.Coating.Indexhighn = 3.48041;          % G.D.Cole
  %ifo.Materials.Coating.Philown = 2e-5;                % guess
  %ifo.Materials.Coating.Indexlown = 2.93833;           % 

  %ifo.Materials.Coating.Phihighn = 1e-5;         % better IBS? (e.g., aSi)
  %ifo.Optics.ITM.CoatingThicknessLown = 0.25;
  %ifo.Optics.ETM.CoatingThicknessLown = 0.3;

  %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
  % Squeezer Parameters
  
  % Define the squeezing you want:
  %   None = ignore the squeezer settings
  %   Freq Independent = nothing special (no filter cavties)
  %   Freq Dependent = applies the specified filter cavites
  ifo.Squeezer.Type = 'Freq Dependent';
  ifo.Squeezer.AmplitudedB = sqzdB;             % SQZ amplitude [dB]
  ifo.Squeezer.SQZAngle = 0;                 % SQZ phase [radians]
  ifo.Squeezer.LOAngleRMS = 10e-3;           % quadrature noise [radians]

  % with these losses (2%, 4%, 20ppm) and 17dB in, 10dB are measured at 5kHz
  ifo.Squeezer.InjectionLoss = 0.02;         % power loss after squeezer
  ifo.Optics.PhotoDetectorEfficiency = 0.96; % 1 - readout loss
  ifo.Optics.Loss = 20e-6;                    % was 37.5ppm 
  ifo.Optics.BSLoss = 1e-4;                   % was 2e-3
  
  % Parameters for frequency dependent squeezing
  fcParams.L = 4e3;            % cavity length
  fcParams.Lrt = 150e-6;       % round-trip loss in the cavity
  fcParams.Te = 5e-6;          % end mirror trasmission
  fcParams.Rot = deg2rad(0);   % phase rotation after cavity (why?)
  
  %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
  % Parameter based computations
  
  % compute ifo info for use in filter cavity calculation
  ifo = precompIFO(ifo);
  
  % compute input mirror transmission and detuning
  ifo.Squeezer.FilterCavity = computeFCParams(ifo, fcParams);
end

function ifo = setCoatingAlGaAs(ifo)

  % from http://www.ioffe.ru/SVA/NSM/Semicond/AlGaAs/  for T = 300K
  % kappa = 55-212*x+248*x^2   (W / (m K))
  % sigma = 0.31 + 0.1*x
  % Y = (85.3 -1.8*x)*1e9    (Pa)
  % Density = 5320 - 1560*x    (kg / m^3)
  % Heat Capacity = (330 + 120*x)
  % CV = (Heat Capacity) * Density
  % alpha = (5.73-0.53*x)*1e-6     (dL/L)/K
  % high index material: Al_{0.12}Ga_{0.88}As
  ifo.Materials.Coating.Yhighn = 85.3e9;
  ifo.Materials.Coating.Sigmahighn = 0.31;             % Poisson's ratio
  ifo.Materials.Coating.CVhighn = 1.69e6;              % Heat Capacity per Volume
  ifo.Materials.Coating.Alphahighn = 5.73e-6;          % 
  ifo.Materials.Coating.Betahighn = 2.67e-4;           % Appl. Phys. Lett. 66, 335 (1995) 
  % name is wrong; should be Thermal Conductivity
  ifo.Materials.Coating.ThermalDiffusivityhighn = 55;  % 
  ifo.Materials.Coating.Phihighn = 2e-5;               % guess
  ifo.Materials.Coating.Indexhighn = 3.48041;          % G.D.Cole
  
  % low index material: Al_{0.92}Ga_{0.08}As
  ifo.Materials.Coating.Ylown = 85.1e9;
  ifo.Materials.Coating.Sigmalown = 0.32;
  ifo.Materials.Coating.CVlown = 1.75e6;               % 
  ifo.Materials.Coating.Alphalown = 5.2e-6;            % 
  ifo.Materials.Coating.Betalown = 1.43e-4;            % dn/dT
  ifo.Materials.Coating.ThermalDiffusivitylown = 91;   % 
  ifo.Materials.Coating.Philown = 2e-5;                % guess
  ifo.Materials.Coating.Indexlown = 2.93833;           % 
end
